==> humid-0.2.0.tar.gz: humid-0.2.0/src/humid/words/animals.py <==
ANIMALS = [
    "aardvark",
    "aardwolf",
    "abac",
    "abacusfish",
    "abalone",
    "acornwoodpecker",
    "affenpinscher",
    "affricanpotto",
    "africanbullfrog",
    "africanclawedfrog",
    "africanelephant",
    "africangrey",
    "agama",
    "agouti",
    "airedale",
    "airedaleterrier",
    "akbac",
    "akbash",
    "akita",
    "albatross",
    "albino",
    "alligator",
    "alligatorgar",
    "alpaca",
    "alpakka",
    "alpine",
    "amberjack",
    "anaconda",
    "angelfish",
    "ant",
    "antbear",
    "antbird",
    "anteater",
    "antelope",
    "aoudad",
    "apalm",
    "ape",
    "arapaima",
    "arcticfox",
    "armadillo",
    "asianhornet",
    "atlanticmackerel",
    "australiancattledog",
    "australianshepherd",
    "australianterrier",
    "avocet",
    "axolotl",
    "babirusa",
    "baboon",
    "bacchus",
    "bactrian",
    "badger",
    "bagworm",
    "bald eagle",
    "baldcypress",
    "baldeagle",
    "bandicoot",
    "barb",
    "barbet",
    "barnacle",
    "barnowl",
    "barracuda",
    "barramundi",
    "barredowl",
    "basset",
    "bat",
    "bear",
    "bearcat",
    "beardeddragon",
    "beardedseal",
    "beardedvulture",
    "beaver",
    "beetle",
    "beetlebug",
    "beluga",
    "bernhardiner",
    "bilby",
    "binturong",
    "birch",
    "bird",
    "bison",
    "black bear",
    "blackbear",
    "blackbird",
    "bloodhound",
    "blowfish",
    "bluejay",
    "boa",
    "boa constrictor",
    "boar",
    "bobcat",
    "bobolink",
    "bongo",
    "bonito",
    "booby",
    "bostonterrier",
    "brambling",
    "brownbear",
    "buffalo",
    "bulldog",
    "bullfrog",
    "bullmoose",
    "burro",
    "butterfly",
    "butterflyfish",
    "caballero",
    "caballo",
    "caballus",
    "cactuswren",
    "caiman",
    "cairn",
    "cairnterrier",
    "calf",
    "camel",
    "canary",
    "capuchin",
    "capybara",
    "caracal",
    "cardinal",
    "caribou",
    "carp",
    "cassowary",
    "cat",
    "catbird",
    "caterpillar",
    "catfish",
    "cattle",
    "cavalier",
    "centaur",
    "centipede",
    "chameleon",
    "cheetah",
    "chickadee",
    "chimera",
    "chimpanzee",
    "chinchilla",
    "chipmunk",
    "cichlid",
    "civet",
    "clams",
    "clownfish",
    "coati",
    "cobra",
    "cobratop",
    "cockatoo",
    "cockroach",
    "collaredlizard",
    "collie",
    "commonseal",
    "condor",
    "coot",
    "coral",
    "cougar",
    "cow",
    "cowbird",
    "coyote",
    "coypu",
    "crab",
    "crane",
    "crestedcrane",
    "crimsonwing",
    "crocodile",
    "crocodilefish",
    "crow",
    "cuckoo",
    "cuttlefish",
    "dachshund",
    "dachsund",
    "daffodil",
    "dalmatian",
    "dalmation",
    "dama",
    "deer",
    "deerhound",
    "dingo",
    "dodo",
    "dog",
    "dogfish",
    "dolphin",
    "dolphinfish",
    "domesticanimal",
    "donkey",
    "dove",
    "dragonfly",
    "dromedary",
    "duck",
    "duckling",
    "dugong",
    "dungbeetle",
    "eagle",
    "eagleowl",
    "earthworm",
    "earwig",
    "echidna",
    "eel",
    "elephant",
    "elephantseal",
    "elk",
    "emu",
    "entlebucher",
    "erlang",
    "euro",
    "eurohound",
    "falcon",
    "falkland",
    "fawn",
    "fennec",
    "fennecfox",
    "ferret",
    "finch",
    "fish",
    "fishingcat",
    "flamingo",
    "flicker",
    "fly",
    "flyingfox",
    "fossa",
    "fox",
    "foxhound",
    "foxterrier",
    "frenchbulldog",
    "frilledlizard",
    "frilledshark",
    "frog",
    "frogfish",
    "fugu",
    "galago",
    "gander",
    "gazelle",
    "gecko",
    "gerbil",
    "giantpanda",
    "gibbon",
    "gila",
    "giraffe",
    "glenofimal",
    "gnu",
    "goat",
    "goatfish",
    "goldenretriever",
    "goldfish",
    "goose",
    "goosefish",
    "gopher",
    "goral",
    "gorilla",
    "gorillagrouper",
    "grasshopper",
    "greatdane",
    "greatwhite",
    "grebe",
    "grizzly",
    "grizzly bear",
    "groundhog",
    "guanaco",
    "guinea",
    "guineapig",
    "gull",
    "guppy",
    "hamadryas",
    "hamster",
    "harbor seal",
    "hare",
    "harlequin",
    "harpy",
    "hawk",
    "hedgehog",
    "hen",
    "hermitcrab",
    "heron",
    "herring",
    "hippopotamus",
    "honey badger",
    "honeybadger",
    "honeybee",
    "hornedtoad",
    "hornet",
    "horse",
    "horseshoecrab",
    "hound",
    "human",
    "hummingbird",
    "hyacinth",
    "hyena",
    "hyrax",
    "ibex",
    "ibis",
    "iguana",
    "impala",
    "inchworm",
    "indigo",
    "indri",
    "insect",
    "irishsetter",
    "ivory",
    "jackal",
    "jackrabbit",
    "jaguar",
    "jaguarundi",
    "jalapeno",
    "jellyfish",
    "jerboa",
    "junglecat",
    "junglefowl",
    "kakapo",
    "kangaroo",
    "kennel",
    "kestrel",
    "killer whale",
    "kingfisher",
    "kinkajou",
    "kiwi",
    "koala",
    "koalabeard",
    "kodiakbear",
    "komodo",
    "komodo dragon",
    "komododragon",
    "kookaburra",
    "kraken",
    "krill",
    "kudu",
    "labrador",
    "ladybug",
    "lamb",
    "langur",
    "lemming",
    "lemonshark",
    "lemur",
    "leopard",
    "leopardseal",
    "liger",
    "linnet",
    "lion",
    "lizard",
    "llama",
    "lobster",
    "longhorn",
    "lori",
    "lorikeet",
    "loris",
    "louse",
    "luna",
    "lynx",
    "lyrebird",
    "maggot",
    "magpie",
    "malayanbear",
    "mallard",
    "manatee",
    "mandrill",
    "manedwolf",
    "mantid",
    "mantis",
    "marabou",
    "marmot",
    "marsupial",
    "martin",
    "meerkat",
    "merlin",
    "millipede",
    "mink",
    "minke",
    "mockingbird",
    "mole",
    "monarch",
    "mongoose",
    "monkey",
    "monkfish",
    "moose",
    "moth",
    "mountainlion",
    "mouse",
    "mouselemur",
    "muskox",
    "muskrat",
    "napoleonfish",
    "narwhal",
    "neonfish",
    "newt",
    "nightjar",
    "numbat",
    "ocelot",
    "octopus",
    "okapi",
    "opossum",
    "orangutan",
    "orca",
    "ostrich",
    "otter",
    "owl",
    "ox",
    "oxpecker",
    "panda",
    "pangolin",
    "parakeet",
    "parrot",
    "parrotfish",
    "pato",
    "peacock",
    "pelican",
    "penguin",
    "pequena",
    "perch",
    "pigeon",
    "platypus",
    "polarbear",
    "porcupine",
    "possum",
    "pufferfish",
    "puffin",
    "puma",
    "python",
    "quail",
    "quokka",
    "quoll",
    "rabbit",
    "raccoon",
    "rat",
    "rattlesnake",
    "raven",
    "redfox",
    "redpanda",
    "reindeer",
    "renard",
    "rhino",
    "rhinoceros",
    "ringtail",
    "robin",
    "rockhopper",
    "rooster",
    "salamander",
    "salmon",
    "sandpiper",
    "sandshark",
    "sawfish",
    "scalyanteater",
    "scorpion",
    "sea lion",
    "seagull",
    "seahorse",
    "seal",
    "sealion",
    "seaotter",
    "seaurchin",
    "serval",
    "shark",
    "shearwater",
    "sheep",
    "shelduck",
    "shrike",
    "shrimp",
    "sifaka",
    "siskin",
    "skimmer",
    "skink",
    "skua",
    "skunk",
    "sloth",
    "slothbear",
    "snail",
    "snake",
    "snappingturtle",
    "snowleopard",
    "snowyowl",
    "sombrero",
    "sparrow",
    "spatula",
    "spider",
    "spinyanteater",
    "squid",
    "squill",
    "squirrel",
    "squirrelfish",
    "starfish",
    "starling",
    "stingray",
    "stoat",
    "stork",
    "sturgeon",
    "sunbear",
    "swallow",
    "swan",
    "tamarin",
    "tamarind",
    "tapir",
    "tarantula",
    "tarpon",
    "tarsier",
    "termite",
    "terrapin",
    "terrier",
    "thrush",
    "tiger",
    "toad",
    "toadfish",
    "tortoise",
    "toucan",
    "treecreeper",
    "treefrog",
    "trout",
    "tuatara",
    "tuna",
    "turkey",
    "turtle",
    "unicornfish",
    "urchin",
    "viper",
    "vole",
    "vulture",
    "wagtail",
    "wallaby",
    "walrus",
    "warthog",
    "wasp",
    "waterbuck",
    "waterbuffalo",
    "weasel",
    "whale",
    "wildebeest",
    "wolf",
    "wolverine",
    "wombat",
    "woodchuck",
    "woodcock",
    "woodpecker",
    "worm",
    "wren",
    "yak",
    "zander",
    "zebra",
    "zebrafish",
    "zebu",
    "zorilla",
    "zorse",
    "zuchon",
    "zuniga",
]

==> humid-0.2.1.tar.gz: humid-0.2.1/src/humid/words/animals.py <==
ANIMALS = [
    "aardvark",
    "aardwolf",
    "abac",
    "abacusfish",
    "abalone",
    # "acornwoodpecker",
    "affenpinscher",
    # "affricanpotto",
    # "africanbullfrog",
    # "africanclawedfrog",
    # "africanelephant",
    # "africangrey",
    "agama",
    "agouti",
    "airedale",
    # "airedaleterrier",
    "akbac",
    "akbash",
    "akita",
    "albatross",
    "albino",
    "alligator",
    # "alligatorgar",
    "alpaca",
    "alpakka",
    "alpine",
    "amberjack",
    "anaconda",
    "angelfish",
    "ant",
    "antbear",
    "antbird",
    "anteater",
    "antelope",
    "aoudad",
    "apalm",
    "ape",
    "arapaima",
    # "arcticfox",
    "armadillo",
    # "asianhornet",
    # "atlanticmackerel",
    # "australiancattledog",
    # "australianshepherd",
    # "australianterrier",
    "avocet",
    "axolotl",
    "babirusa",
    "baboon",
    "bacchus",
    "bactrian",
    "badger",
    "bagworm",
    "bald eagle",
    "baldcypress",
    "baldeagle",
    "bandicoot",
    "barb",
    "barbet",
    "barnacle",
    "barnowl",
    "barracuda",
    "barramundi",
    "barredowl",
    "basset",
    "bat",
    "bear",
    "bearcat",
    "beardeddragon",
    "beardedseal",
    "beardedvulture",
    "beaver",
    "beetle",
    "beetlebug",
    "beluga",
    "bernhardiner",
    "bilby",
    "binturong",
    "birch",
    "bird",
    "bison",
    "black bear",
    "blackbear",
    "blackbird",
    "bloodhound",
    "blowfish",
    "bluejay",
    "boa",
    # "boa constrictor",
    "boar",
    "bobcat",
    "bobolink",
    "bongo",
    "bonito",
    "booby",
    # "bostonterrier",
    "brambling",
    # "brownbear",
    "buffalo",
    "bulldog",
    "bullfrog",
    "bullmoose",
    "burro",
    "butterfly",
    "butterflyfish",
    "caballero",
    "caballo",
    "caballus",
    # "cactuswren",
    "caiman",
    "cairn",
    "cairnterrier",
    "calf",
    "camel",
    "canary",
    "capuchin",
    "capybara",
    "caracal",
    "cardinal",
    "caribou",
    "carp",
    "cassowary",
    "cat",
    "catbird",
    "caterpillar",
    "catfish",
    "cattle",
    "cavalier",
    "centaur",
    "centipede",
    "chameleon",
    "cheetah",
    "chickadee",
    "chimera",
    "chimpanzee",
    "chinchilla",
    "chipmunk",
    "cichlid",
    "civet",
    "clams",
    "clownfish",
    "coati",
    "cobra",
    "cobratop",
    "cockatoo",
    "cockroach",
    # "collaredlizard",
    "collie",
    "commonseal",
    "condor",
    "coot",
    "coral",
    "cougar",
    "cow",
    "cowbird",
    "coyote",
    "coypu",
    "crab",
    "crane",
    "crestedcrane",
    "crimsonwing",
    "crocodile",
    "crocodilefish",
    "crow",
    "cuckoo",
    "cuttlefish",
    "dachshund",
    "dachsund",
    "daffodil",
    "dalmatian",
    "dalmation",
    "dama",
    "deer",
    "deerhound",
    "dingo",
    "dodo",
    "dog",
    "dogfish",
    "dolphin",
    "dolphinfish",
    # "domesticanimal",
    "donkey",
    "dove",
    "dragonfly",
    "dromedary",
    "duck",
    "duckling",
    "dugong",
    "dungbeetle",
    "eagle",
    # "eagleowl",
    "earthworm",
    "earwig",
    "echidna",
    "eel",
    "elephant",
    "elephantseal",
    "elk",
    "emu",
    "entlebucher",
    "erlang",
    "euro",
    "eurohound",
    "falcon",
    "falkland",
    "fawn",
    "fennec",
    # "fennecfox",
    "ferret",
    "finch",
    "fish",
    "fishingcat",
    "flamingo",
    "flicker",
    "fly",
    "flyingfox",
    "fossa",
    "fox",
    "foxhound",
    "foxterrier",
    "frenchbulldog",
    "frilledlizard",
    "frilledshark",
    "frog",
    "frogfish",
    "fugu",
    "galago",
    "gander",
    "gazelle",
    "gecko",
    "gerbil",
    "giantpanda",
    "gibbon",
    "gila",
    "giraffe",
    "glenofimal",
    "gnu",
    "goat",
    "goatfish",
    "goldenretriever",
    "goldfish",
    "goose",
    "goosefish",
    "gopher",
    "goral",
    "gorilla",
    "gorillagrouper",
    "grasshopper",
    "greatdane",
    "greatwhite",
    "grebe",
    "grizzly",
    "grizzly bear",
    "groundhog",
    "guanaco",
    "guinea",
    "guineapig",
    "gull",
    "guppy",
    "hamadryas",
    "hamster",
    "harbor seal",
    "hare",
    "harlequin",
    "harpy",
    "hawk",
    "hedgehog",
    "hen",
    "hermitcrab",
    "heron",
    "herring",
    "hippopotamus",
    "honey badger",
    "honeybadger",
    "honeybee",
    "hornedtoad",
    "hornet",
    "horse",
    "horseshoecrab",
    "hound",
    "human",
    "hummingbird",
    "hyacinth",
    "hyena",
    "hyrax",
    "ibex",
    "ibis",
    "iguana",
    "impala",
    "inchworm",
    "indigo",
    "indri",
    "insect",
    "irishsetter",
    "ivory",
    "jackal",
    "jackrabbit",
    "jaguar",
    "jaguarundi",
    "jalapeno",
    "jellyfish",
    "jerboa",
    "junglecat",
    "junglefowl",
    "kakapo",
    "kangaroo",
    "kennel",
    "kestrel",
    "killerwhale",
    "kingfisher",
    "kinkajou",
    "kiwi",
    "koala",
    "koala beard",
    "kodiakbear",
    "komodo",
    # "komodo dragon",
    "komododragon",
    "kookaburra",
    "kraken",
    "krill",
    "kudu",
    "labrador",
    "ladybug",
    "lamb",
    "langur",
    "lemming",
    "lemonshark",
    "lemur",
    "leopard",
    "leopardseal",
    "liger",
    "linnet",
    "lion",
    "lizard",
    "llama",
    "lobster",
    "longhorn",
    "lori",
    "lorikeet",
    "loris",
    "louse",
    "luna",
    "lynx",
    "lyrebird",
    "maggot",
    "magpie",
    "malayanbear",
    "mallard",
    "manatee",
    "mandrill",
    "manedwolf",
    "mantid",
    "mantis",
    "marabou",
    "marmot",
    "marsupial",
    "martin",
    "meerkat",
    "merlin",
    "millipede",
    "mink",
    "minke",
    "mockingbird",
    "mole",
    "monarch",
    "mongoose",
    "monkey",
    "monkfish",
    "moose",
    "moth",
    "mountainlion",
    "mouse",
    "mouselemur",
    "muskox",
    "muskrat",
    "napoleonfish",
    "narwhal",
    "neonfish",
    "newt",
    "nightjar",
    "numbat",
    "ocelot",
    "octopus",
    "okapi",
    "opossum",
    "orangutan",
    "orca",
    "ostrich",
    "otter",
    "owl",
    "ox",
    # "oxpecker",
    "panda",
    "pangolin",
    "parakeet",
    "parrot",
    "parrotfish",
    # "pato",
    "peacock",
    "pelican",
    "penguin",
    "pequena",
    "perch",
    "pigeon",
    "platypus",
    "polarbear",
    "porcupine",
    "possum",
    "pufferfish",
    "puffin",
    "puma",
    "python",
    "quail",
    "quokka",
    "quoll",
    "rabbit",
    "raccoon",
    "rat",
    "rattlesnake",
    "raven",
    "redfox",
    "redpanda",
    "reindeer",
    "renard",
    "rhino",
    "rhinoceros",
    "ringtail",
    "robin",
    "rockhopper",
    "rooster",
    "salamander",
    "salmon",
    "sandpiper",
    "sandshark",
    "sawfish",
    "scalyanteater",
    "scorpion",
    "sea lion",
    "seagull",
    "seahorse",
    "seal",
    "sealion",
    "seaotter",
    "seaurchin",
    "serval",
    "shark",
    "shearwater",
    "sheep",
    "shelduck",
    "shrike",
    "shrimp",
    "sifaka",
    "siskin",
    "skimmer",
    "skink",
    "skua",
    "skunk",
    "sloth",
    "slothbear",
    "snail",
    "snake",
    "snappingturtle",
    "snowleopard",
    "snowyowl",
    "sombrero",
    "sparrow",
    "spatula",
    "spider",
    "spinyanteater",
    "squid",
    "squill",
    "squirrel",
    "squirrelfish",
    "starfish",
    "starling",
    "stingray",
    "stoat",
    "stork",
    "sturgeon",
    "sunbear",
    "swallow",
    "swan",
    "tamarin",
    "tamarind",
    "tapir",
    "tarantula",
    "tarpon",
    "tarsier",
    "termite",
    "terrapin",
    "terrier",
    "thrush",
    "tiger",
    "toad",
    "toadfish",
    "tortoise",
    "toucan",
    "treecreeper",
    "treefrog",
    "trout",
    "tuatara",
    "tuna",
    "turkey",
    "turtle",
    "unicornfish",
    "urchin",
    "viper",
    "vole",
    "vulture",
    "wagtail",
    "wallaby",
    "walrus",
    "warthog",
    "wasp",
    "waterbuck",
    "waterbuffalo",
    "weasel",
    "whale",
    "wildebeest",
    "wolf",
    "wolverine",
    "wombat",
    "woodchuck",
    "woodcock",
    "woodpecker",
    "worm",
    "wren",
    "yak",
    "zander",
    "zebra",
    "zebrafish",
    "zebu",
    "zorilla",
    "zorse",
    "zuchon",
    "zuniga",
]
